@@ -5,11 +5,12 @@ SPDX-License-Identifier: MIT-0
 
 from __future__ import annotations
 
+import os
 from abc import ABC, abstractmethod
 from collections import deque
 from dataclasses import InitVar, dataclass, field, fields
 from functools import lru_cache
-from typing import Any, Deque, Iterator, Sequence, Set, Tuple
+from typing import TYPE_CHECKING, Any, Deque, Iterator, Sequence, Set, Tuple
 
 from cfnlint.context._mappings import Mappings
 from cfnlint.context.conditions._conditions import Conditions
@@ -18,10 +19,14 @@ from cfnlint.helpers import (
     FUNCTIONS,
     PSEUDOPARAMS,
     REGION_PRIMARY,
+    TRANSFORM_LANGUAGE_EXTENSION,
     TRANSFORM_SAM,
 )
 from cfnlint.schema import PROVIDER_SCHEMA_MANAGER, AttributeDict
 
+if TYPE_CHECKING:
+    from cfnlint.template import Template
+
 _PSEUDOPARAMS_NON_REGION = ["AWS::AccountId", "AWS::NoValue", "AWS::StackName"]
 
 
@@ -48,10 +53,11 @@ class Transforms:
         )
 
     def has_language_extensions_transform(self):
-        lang_extensions_transform = "AWS::LanguageExtensions"
-        return bool(lang_extensions_transform in self._transforms)
+        return bool(TRANSFORM_LANGUAGE_EXTENSION in self._transforms)
 
     def has_sam_transform(self):
+        # this function will always return False as SAM transform
+        # will eliminate itself when the transform is done
         return bool(TRANSFORM_SAM in self._transforms)
 
 
@@ -161,6 +167,7 @@ class Context:
 
     # is the value a resolved value
     is_resolved_value: bool = field(init=True, default=False)
+    resolve_pseudo_parameters: bool = field(init=True, default=True)
 
     def evolve(self, **kwargs) -> "Context":
         """
@@ -180,8 +187,11 @@ class Context:
         return cls(**kwargs)
 
     def ref_value(self, instance: str) -> Iterator[Tuple[str | list[str], "Context"]]:
-        if instance in PSEUDOPARAMS and instance not in self.pseudo_parameters:
-            return
+        if instance in PSEUDOPARAMS:
+            if not self.resolve_pseudo_parameters:
+                return
+            if instance not in self.pseudo_parameters:
+                return
 
         if instance in self.ref_values:
             yield self.ref_values[instance], self
@@ -194,7 +204,7 @@ class Context:
                 yield pseudo_value, self.evolve(ref_values={instance: pseudo_value})
             return
         if instance in self.parameters:
-            for v, path in self.parameters[instance].ref(self):
+            for v, path in self.parameters[instance].ref_value(self):
 
                 # validate that ref is possible with path
                 # need to evaluate if Fn::If would be not true if value is
@@ -274,7 +284,11 @@ class _Ref(ABC):
     """
 
     @abstractmethod
-    def ref(self, context: Context) -> Iterator[Any]:
+    def ref(self, region: str) -> dict[str, Any]:
+        pass
+
+    @abstractmethod
+    def ref_value(self, context: Context) -> Iterator[Tuple[Any, deque]]:
         pass
 
 
@@ -347,7 +361,10 @@ class Parameter(_Ref):
         if parameter.get("NoEcho") in list(BOOLEAN_STRINGS_TRUE) + [True]:
             self.no_echo = True
 
-    def ref(self, context: Context) -> Iterator[Tuple[Any, deque]]:
+    def ref(self, region: str = REGION_PRIMARY) -> dict[str, Any]:
+        return {}
+
+    def ref_value(self, context: Context) -> Iterator[Tuple[Any, deque]]:
         if self.allowed_values:
             for i, allowed_value in enumerate(self.allowed_values):
                 if isinstance(allowed_value, list):
@@ -373,6 +390,37 @@ class Parameter(_Ref):
         return self.type.startswith("AWS::SSM::Parameter::")
 
 
+def _nested_stack_get_atts(filename: str, template_url: str) -> None | AttributeDict:
+    if (
+        template_url.startswith("http://")
+        or template_url.startswith("https://")
+        or template_url.startswith("s3://")
+    ):
+        return None
+
+    base_dir = os.path.dirname(os.path.abspath(filename))
+    template_path = os.path.normpath(os.path.join(base_dir, template_url))
+
+    try:
+        from cfnlint.decode import decode
+
+        (tmp, matches) = decode(template_path)
+    except Exception:  # noqa: E722
+        return None
+    if matches or tmp is None:
+        return None
+
+    outputs = AttributeDict()
+
+    tmp_outputs = tmp.get("Outputs")
+    if not isinstance(tmp_outputs, dict):
+        return outputs
+
+    for name, _ in tmp_outputs.items():
+        outputs[f"Outputs.{name}"] = "/properties/CfnLintStringType"
+    return outputs
+
+
 @dataclass
 class Resource(_Ref):
     """
@@ -382,8 +430,10 @@ class Resource(_Ref):
     type: str = field(init=False)
     condition: str | None = field(init=False, default=None)
     resource: InitVar[Any]
+    filename: InitVar[str | None] = field(default=None)
+    _nested_stack_get_atts: AttributeDict | None = field(init=False, default=None)
 
-    def __post_init__(self, resource) -> None:
+    def __post_init__(self, resource: Any, filename: str | None) -> None:
         if not isinstance(resource, dict):
             raise ValueError("Resource must be a object")
         t = resource.get("Type")
@@ -398,10 +448,27 @@ class Resource(_Ref):
             raise ValueError("Condition must be a string")
         self.condition = c
 
-    def get_atts(self, region: str = "us-east-1") -> AttributeDict:
+        if filename is None:
+            return
+
+        if self.type == "AWS::CloudFormation::Stack":
+            properties = resource.get("Properties")
+            if isinstance(properties, dict):
+                template_url = properties.get("TemplateURL")
+                if isinstance(template_url, str):
+                    self._nested_stack_get_atts = _nested_stack_get_atts(
+                        filename, template_url
+                    )
+
+    def get_atts(self, region: str = REGION_PRIMARY) -> AttributeDict:
+        if self._nested_stack_get_atts is not None:
+            return self._nested_stack_get_atts
         return PROVIDER_SCHEMA_MANAGER.get_type_getatts(self.type, region)
 
-    def ref(self, context: Context) -> Iterator[Any]:
+    def ref(self, region: str = REGION_PRIMARY) -> dict[str, Any]:
+        return PROVIDER_SCHEMA_MANAGER.get_type_ref(self.type, region)
+
+    def ref_value(self, context: Context) -> Iterator[Tuple[Any, deque]]:
         return
         yield
 
@@ -419,13 +486,13 @@ def _init_parameters(parameters: Any) -> dict[str, Parameter]:
     return obj
 
 
-def _init_resources(resources: Any) -> dict[str, Resource]:
+def _init_resources(resources: Any, filename: str | None = None) -> dict[str, Resource]:
     obj = {}
     if not isinstance(resources, dict):
         raise ValueError("Resource must be a object")
     for k, v in resources.items():
         try:
-            obj[k] = Resource(v)
+            obj[k] = Resource(v, filename)
         except ValueError:
             pass
     return obj
@@ -437,7 +504,7 @@ def _init_transforms(transforms: Any) -> Transforms:
     return Transforms([])
 
 
-def create_context_for_template(cfn):
+def create_context_for_template(cfn: Template) -> "Context":
     parameters = {}
     try:
         parameters = _init_parameters(cfn.template.get("Parameters", {}))
@@ -446,7 +513,7 @@ def create_context_for_template(cfn):
 
     resources = {}
     try:
-        resources = _init_resources(cfn.template.get("Resources", {}))
+        resources = _init_resources(cfn.template.get("Resources", {}), cfn.filename)
     except (ValueError, AttributeError):
         pass
 
