@@ -109,7 +109,9 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
+    "AWS::ApplicationSignals::Discovery",
     "AWS::ApplicationSignals::ServiceLevelObjective",
+    "AWS::Athena::CapacityReservation",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
     "AWS::Athena::PreparedStatement",
@@ -132,6 +134,7 @@ types: list[str] = [
     "AWS::Backup::RestoreTestingSelection",
     "AWS::BackupGateway::Hypervisor",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
@@ -564,6 +567,7 @@ types: list[str] = [
     "AWS::GuardDuty::MalwareProtectionPlan",
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::HealthLake::FHIRDatastore",
     "AWS::IAM::AccessKey",
@@ -836,6 +840,7 @@ types: list[str] = [
     "AWS::Oam::Sink",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
     "AWS::OpenSearchServerless::LifecyclePolicy",
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
@@ -993,6 +998,8 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -1198,6 +1205,7 @@ types: list[str] = [
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
+    "AWS::XRay::TransactionSearchConfig",
     "Alexa::ASK::Skill",
     "Module",
 ]
@@ -1242,12 +1250,10 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1271,6 +1277,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
+    "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -1303,6 +1310,7 @@ cached: list[str] = [
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
+    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -1311,6 +1319,7 @@ cached: list[str] = [
     "aws-aps-workspace.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
+    "aws-athena-capacityreservation.json",
     "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
@@ -1333,6 +1342,7 @@ cached: list[str] = [
     "aws-backup-restoretestingselection.json",
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
@@ -1343,7 +1353,6 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
@@ -1434,6 +1443,7 @@ cached: list[str] = [
     "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
+    "aws-cognito-userpooldomain.json",
     "aws-cognito-userpoolgroup.json",
     "aws-cognito-userpoolidentityprovider.json",
     "aws-cognito-userpoolresourceserver.json",
@@ -1707,6 +1717,7 @@ cached: list[str] = [
     "aws-gamelift-build.json",
     "aws-gamelift-fleet.json",
     "aws-gamelift-gameservergroup.json",
+    "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-location.json",
     "aws-gamelift-script.json",
     "aws-globalaccelerator-accelerator.json",
@@ -1758,6 +1769,7 @@ cached: list[str] = [
     "aws-guardduty-malwareprotectionplan.json",
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-healthlake-fhirdatastore.json",
     "aws-iam-accesskey.json",
@@ -1843,6 +1855,7 @@ cached: list[str] = [
     "aws-iotsitewise-assetmodel.json",
     "aws-iotsitewise-dashboard.json",
     "aws-iotsitewise-gateway.json",
+    "aws-iotsitewise-portal.json",
     "aws-iotsitewise-project.json",
     "aws-iottwinmaker-componenttype.json",
     "aws-iottwinmaker-entity.json",
@@ -1869,7 +1882,6 @@ cached: list[str] = [
     "aws-kendra-index.json",
     "aws-kendraranking-executionplan.json",
     "aws-kinesis-resourcepolicy.json",
-    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
@@ -2020,6 +2032,7 @@ cached: list[str] = [
     "aws-oam-sink.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
     "aws-opensearchserverless-lifecyclepolicy.json",
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
@@ -2151,12 +2164,14 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
@@ -2170,6 +2185,8 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-cluster.json",
@@ -2324,9 +2341,6 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
-    "aws-vpclattice-listener.json",
-    "aws-vpclattice-resourceconfiguration.json",
-    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
@@ -2368,5 +2382,6 @@ cached: list[str] = [
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
     "aws-xray-samplingrule.json",
+    "aws-xray-transactionsearchconfig.json",
     "module.json",
 ]
