@@ -110,6 +110,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
+    "AWS::ApplicationSignals::Discovery",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::CapacityReservation",
     "AWS::Athena::DataCatalog",
@@ -134,6 +135,7 @@ types: list[str] = [
     "AWS::Backup::RestoreTestingSelection",
     "AWS::BackupGateway::Hypervisor",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
@@ -338,6 +340,7 @@ types: list[str] = [
     "AWS::DataSync::LocationSMB",
     "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
+    "AWS::DataZone::Connection",
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
     "AWS::DataZone::Environment",
@@ -629,6 +632,7 @@ types: list[str] = [
     "AWS::GuardDuty::MalwareProtectionPlan",
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
@@ -892,6 +896,7 @@ types: list[str] = [
     "AWS::Omics::Workflow",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
     "AWS::OpenSearchServerless::LifecyclePolicy",
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
@@ -1051,6 +1056,7 @@ types: list[str] = [
     "AWS::S3::MultiRegionAccessPointPolicy",
     "AWS::S3::StorageLens",
     "AWS::S3::StorageLensGroup",
+    "AWS::S3Express::AccessPoint",
     "AWS::S3Express::BucketPolicy",
     "AWS::S3Express::DirectoryBucket",
     "AWS::S3ObjectLambda::AccessPoint",
@@ -1059,6 +1065,8 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -1277,6 +1285,7 @@ types: list[str] = [
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
+    "AWS::XRay::TransactionSearchConfig",
     "Alexa::ASK::Skill",
     "Module",
 ]
@@ -1321,12 +1330,10 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1351,6 +1358,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
+    "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -1385,6 +1393,7 @@ cached: list[str] = [
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
+    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -1416,6 +1425,7 @@ cached: list[str] = [
     "aws-backup-restoretestingselection.json",
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
@@ -1428,7 +1438,6 @@ cached: list[str] = [
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
-    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-budgets-budget.json",
@@ -1603,6 +1612,7 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
+    "aws-datazone-connection.json",
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
     "aws-datazone-environment.json",
@@ -1904,6 +1914,7 @@ cached: list[str] = [
     "aws-guardduty-malwareprotectionplan.json",
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-iam-accesskey.json",
     "aws-iam-group.json",
@@ -1974,6 +1985,7 @@ cached: list[str] = [
     "aws-iotsitewise-assetmodel.json",
     "aws-iotsitewise-dashboard.json",
     "aws-iotsitewise-gateway.json",
+    "aws-iotsitewise-portal.json",
     "aws-iotsitewise-project.json",
     "aws-iottwinmaker-componenttype.json",
     "aws-iottwinmaker-entity.json",
@@ -1988,7 +2000,6 @@ cached: list[str] = [
     "aws-kendra-index.json",
     "aws-kendraranking-executionplan.json",
     "aws-kinesis-resourcepolicy.json",
-    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-application.json",
     "aws-kinesisanalytics-applicationoutput.json",
@@ -2160,6 +2171,7 @@ cached: list[str] = [
     "aws-omics-workflow.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
     "aws-opensearchserverless-lifecyclepolicy.json",
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
@@ -2307,8 +2319,10 @@ cached: list[str] = [
     "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
+    "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
@@ -2322,6 +2336,8 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-cluster.json",
@@ -2509,8 +2525,6 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
-    "aws-wafv2-rulegroup.json",
-    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-wisdom-aiagent.json",
     "aws-wisdom-aiagentversion.json",
@@ -2538,5 +2552,6 @@ cached: list[str] = [
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
     "aws-xray-samplingrule.json",
+    "aws-xray-transactionsearchconfig.json",
     "module.json",
 ]
