@@ -102,6 +102,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
+    "AWS::ApplicationSignals::Discovery",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -125,6 +126,7 @@ types: list[str] = [
     "AWS::Backup::RestoreTestingSelection",
     "AWS::BackupGateway::Hypervisor",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
@@ -314,6 +316,7 @@ types: list[str] = [
     "AWS::DataSync::LocationSMB",
     "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
+    "AWS::DataZone::Connection",
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
     "AWS::DataZone::Environment",
@@ -555,6 +558,7 @@ types: list[str] = [
     "AWS::GuardDuty::MalwareProtectionPlan",
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
@@ -785,15 +789,12 @@ types: list[str] = [
     "AWS::NetworkManager::TransitGatewayRegistration",
     "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
     "AWS::NetworkManager::VpcAttachment",
-    "AWS::NimbleStudio::LaunchProfile",
-    "AWS::NimbleStudio::StreamingImage",
-    "AWS::NimbleStudio::Studio",
-    "AWS::NimbleStudio::StudioComponent",
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
     "AWS::OpenSearchServerless::LifecyclePolicy",
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
@@ -944,6 +945,8 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -1161,6 +1164,7 @@ types: list[str] = [
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
+    "AWS::XRay::TransactionSearchConfig",
     "Alexa::ASK::Skill",
     "Module",
 ]
@@ -1205,12 +1209,10 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1235,6 +1237,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
+    "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -1288,6 +1291,7 @@ cached: list[str] = [
     "aws-backup-restoretestingselection.json",
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
@@ -1298,7 +1302,6 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
@@ -1385,6 +1388,7 @@ cached: list[str] = [
     "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
+    "aws-cognito-userpooldomain.json",
     "aws-cognito-userpoolgroup.json",
     "aws-cognito-userpoolidentityprovider.json",
     "aws-cognito-userpoolresourceserver.json",
@@ -1461,6 +1465,7 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
+    "aws-datazone-connection.json",
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
     "aws-datazone-environment.json",
@@ -1710,6 +1715,7 @@ cached: list[str] = [
     "aws-guardduty-malwareprotectionplan.json",
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-iam-accesskey.json",
     "aws-iam-group.json",
@@ -1780,6 +1786,7 @@ cached: list[str] = [
     "aws-iotsitewise-assetmodel.json",
     "aws-iotsitewise-dashboard.json",
     "aws-iotsitewise-gateway.json",
+    "aws-iotsitewise-portal.json",
     "aws-iotsitewise-project.json",
     "aws-kafkaconnect-connector.json",
     "aws-kafkaconnect-customplugin.json",
@@ -1789,7 +1796,6 @@ cached: list[str] = [
     "aws-kendra-index.json",
     "aws-kendraranking-executionplan.json",
     "aws-kinesis-resourcepolicy.json",
-    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
@@ -1933,14 +1939,11 @@ cached: list[str] = [
     "aws-networkmanager-transitgatewayregistration.json",
     "aws-networkmanager-transitgatewayroutetableattachment.json",
     "aws-networkmanager-vpcattachment.json",
-    "aws-nimblestudio-launchprofile.json",
-    "aws-nimblestudio-streamingimage.json",
-    "aws-nimblestudio-studio.json",
-    "aws-nimblestudio-studiocomponent.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
     "aws-opensearchserverless-lifecyclepolicy.json",
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
@@ -2011,6 +2014,7 @@ cached: list[str] = [
     "aws-rds-customdbengineversion.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
+    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
@@ -2072,8 +2076,10 @@ cached: list[str] = [
     "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
+    "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
@@ -2085,6 +2091,8 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
@@ -2239,9 +2247,6 @@ cached: list[str] = [
     "aws-voiceid-domain.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
-    "aws-vpclattice-listener.json",
-    "aws-vpclattice-resourceconfiguration.json",
-    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
@@ -2295,5 +2300,6 @@ cached: list[str] = [
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
     "aws-xray-samplingrule.json",
+    "aws-xray-transactionsearchconfig.json",
     "module.json",
 ]
