@@ -46,6 +46,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
     "AWS::ApiGatewayV2::Stage",
+    "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
     "AWS::AppConfig::ConfigurationProfile",
     "AWS::AppConfig::Deployment",
@@ -76,6 +77,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
+    "AWS::ApplicationSignals::Discovery",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -92,6 +94,7 @@ types: list[str] = [
     "AWS::Backup::BackupVault",
     "AWS::Backup::LogicallyAirGappedBackupVault",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
@@ -352,6 +355,7 @@ types: list[str] = [
     "AWS::Events::Rule",
     "AWS::FMS::NotificationChannel",
     "AWS::FMS::Policy",
+    "AWS::FMS::ResourceSet",
     "AWS::FSx::DataRepositoryAssociation",
     "AWS::FSx::FileSystem",
     "AWS::FSx::Snapshot",
@@ -386,6 +390,7 @@ types: list[str] = [
     "AWS::GuardDuty::MalwareProtectionPlan",
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
@@ -441,6 +446,7 @@ types: list[str] = [
     "AWS::Lambda::LayerVersionPermission",
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
+    "AWS::LaunchWizard::Deployment",
     "AWS::Logs::AccountPolicy",
     "AWS::Logs::Delivery",
     "AWS::Logs::DeliveryDestination",
@@ -513,6 +519,11 @@ types: list[str] = [
     "AWS::Organizations::OrganizationalUnit",
     "AWS::Organizations::Policy",
     "AWS::Organizations::ResourcePolicy",
+    "AWS::PCAConnectorAD::Connector",
+    "AWS::PCAConnectorAD::DirectoryRegistration",
+    "AWS::PCAConnectorAD::ServicePrincipalName",
+    "AWS::PCAConnectorAD::Template",
+    "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
     "AWS::PCAConnectorSCEP::Challenge",
     "AWS::PCAConnectorSCEP::Connector",
     "AWS::RAM::Permission",
@@ -718,6 +729,7 @@ types: list[str] = [
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
+    "AWS::XRay::TransactionSearchConfig",
     "Module",
 ]
 
@@ -730,6 +742,7 @@ cached: list[str] = [
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
+    "aws-amazonmq-configuration.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
@@ -739,6 +752,7 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
@@ -751,18 +765,17 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
     "aws-apigatewayv2-stage.json",
+    "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
@@ -773,6 +786,7 @@ cached: list[str] = [
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
+    "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -798,10 +812,12 @@ cached: list[str] = [
     "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
+    "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-backup-logicallyairgappedbackupvault.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
@@ -843,7 +859,6 @@ cached: list[str] = [
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-vpcorigin.json",
     "aws-cloudtrail-dashboard.json",
-    "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
@@ -852,7 +867,6 @@ cached: list[str] = [
     "aws-cloudwatch-dashboard.json",
     "aws-cloudwatch-insightrule.json",
     "aws-cloudwatch-metricstream.json",
-    "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
     "aws-codedeploy-application.json",
@@ -866,6 +880,7 @@ cached: list[str] = [
     "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
+    "aws-cognito-userpooldomain.json",
     "aws-cognito-userpoolgroup.json",
     "aws-cognito-userpoolidentityprovider.json",
     "aws-cognito-userpoolresourceserver.json",
@@ -907,6 +922,7 @@ cached: list[str] = [
     "aws-dms-instanceprofile.json",
     "aws-dms-migrationproject.json",
     "aws-dms-replicationconfig.json",
+    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
@@ -951,6 +967,7 @@ cached: list[str] = [
     "aws-ec2-securitygroupingress.json",
     "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
+    "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
@@ -991,6 +1008,7 @@ cached: list[str] = [
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
+    "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-replicationconfiguration.json",
@@ -1041,6 +1059,7 @@ cached: list[str] = [
     "aws-events-rule.json",
     "aws-fms-notificationchannel.json",
     "aws-fms-policy.json",
+    "aws-fms-resourceset.json",
     "aws-fsx-datarepositoryassociation.json",
     "aws-fsx-filesystem.json",
     "aws-fsx-snapshot.json",
@@ -1052,6 +1071,7 @@ cached: list[str] = [
     "aws-globalaccelerator-listener.json",
     "aws-glue-classifier.json",
     "aws-glue-connection.json",
+    "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
     "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
@@ -1071,6 +1091,7 @@ cached: list[str] = [
     "aws-guardduty-malwareprotectionplan.json",
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
@@ -1097,7 +1118,6 @@ cached: list[str] = [
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-workflow.json",
     "aws-kinesis-resourcepolicy.json",
-    "aws-kinesis-stream.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
@@ -1115,6 +1135,7 @@ cached: list[str] = [
     "aws-lambda-function.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
+    "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
@@ -1181,6 +1202,11 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-pcaconnectorad-connector.json",
+    "aws-pcaconnectorad-directoryregistration.json",
+    "aws-pcaconnectorad-serviceprincipalname.json",
+    "aws-pcaconnectorad-template.json",
+    "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
     "aws-pcaconnectorscep-challenge.json",
     "aws-pcaconnectorscep-connector.json",
     "aws-ram-permission.json",
@@ -1243,6 +1269,7 @@ cached: list[str] = [
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
@@ -1252,6 +1279,7 @@ cached: list[str] = [
     "aws-s3outposts-endpoint.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
+    "aws-sagemaker-domain.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
     "aws-sagemaker-imageversion.json",
@@ -1263,6 +1291,7 @@ cached: list[str] = [
     "aws-sagemaker-project.json",
     "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
+    "aws-sagemaker-userprofile.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
@@ -1313,9 +1342,12 @@ cached: list[str] = [
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
+    "aws-sns-topicpolicy.json",
     "aws-sqs-queue.json",
     "aws-sqs-queueinlinepolicy.json",
+    "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
+    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
@@ -1348,7 +1380,6 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
-    "aws-vpclattice-listener.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
@@ -1361,12 +1392,11 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
-    "aws-wafv2-rulegroup.json",
-    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
     "aws-xray-samplingrule.json",
+    "aws-xray-transactionsearchconfig.json",
     "module.json",
 ]
