@@ -107,6 +107,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
+    "AWS::ApplicationSignals::Discovery",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::CapacityReservation",
     "AWS::Athena::DataCatalog",
@@ -135,6 +136,7 @@ types: list[str] = [
     "AWS::Backup::RestoreTestingSelection",
     "AWS::BackupGateway::Hypervisor",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
@@ -207,6 +209,7 @@ types: list[str] = [
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
+    "AWS::CloudFront::VpcOrigin",
     "AWS::CloudTrail::Channel",
     "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
@@ -285,6 +288,7 @@ types: list[str] = [
     "AWS::DMS::ReplicationInstance",
     "AWS::DMS::ReplicationSubnetGroup",
     "AWS::DMS::ReplicationTask",
+    "AWS::DSQL::Cluster",
     "AWS::DataBrew::Dataset",
     "AWS::DataBrew::Job",
     "AWS::DataBrew::Project",
@@ -306,6 +310,7 @@ types: list[str] = [
     "AWS::DataSync::LocationSMB",
     "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
+    "AWS::DataZone::Connection",
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
     "AWS::DataZone::Environment",
@@ -320,11 +325,13 @@ types: list[str] = [
     "AWS::Deadline::Farm",
     "AWS::Deadline::Fleet",
     "AWS::Deadline::LicenseEndpoint",
+    "AWS::Deadline::Limit",
     "AWS::Deadline::MeteredProduct",
     "AWS::Deadline::Monitor",
     "AWS::Deadline::Queue",
     "AWS::Deadline::QueueEnvironment",
     "AWS::Deadline::QueueFleetAssociation",
+    "AWS::Deadline::QueueLimitAssociation",
     "AWS::Deadline::StorageProfile",
     "AWS::Detective::Graph",
     "AWS::Detective::MemberInvitation",
@@ -389,6 +396,11 @@ types: list[str] = [
     "AWS::EC2::PlacementGroup",
     "AWS::EC2::PrefixList",
     "AWS::EC2::Route",
+    "AWS::EC2::RouteServer",
+    "AWS::EC2::RouteServerAssociation",
+    "AWS::EC2::RouteServerEndpoint",
+    "AWS::EC2::RouteServerPeer",
+    "AWS::EC2::RouteServerPropagation",
     "AWS::EC2::RouteTable",
     "AWS::EC2::SecurityGroup",
     "AWS::EC2::SecurityGroupEgress",
@@ -543,6 +555,8 @@ types: list[str] = [
     "AWS::GameLift::MatchmakingConfiguration",
     "AWS::GameLift::MatchmakingRuleSet",
     "AWS::GameLift::Script",
+    "AWS::GameLiftStreams::Application",
+    "AWS::GameLiftStreams::StreamGroup",
     "AWS::GlobalAccelerator::Accelerator",
     "AWS::GlobalAccelerator::CrossAccountAttachment",
     "AWS::GlobalAccelerator::EndpointGroup",
@@ -596,6 +610,7 @@ types: list[str] = [
     "AWS::GuardDuty::MalwareProtectionPlan",
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::HealthLake::FHIRDatastore",
     "AWS::IAM::AccessKey",
@@ -850,6 +865,7 @@ types: list[str] = [
     "AWS::Oam::Sink",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
     "AWS::OpenSearchServerless::LifecyclePolicy",
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
@@ -1005,6 +1021,13 @@ types: list[str] = [
     "AWS::SES::ContactList",
     "AWS::SES::DedicatedIpPool",
     "AWS::SES::EmailIdentity",
+    "AWS::SES::MailManagerAddonInstance",
+    "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerArchive",
+    "AWS::SES::MailManagerIngressPoint",
+    "AWS::SES::MailManagerRelay",
+    "AWS::SES::MailManagerRuleSet",
+    "AWS::SES::MailManagerTrafficPolicy",
     "AWS::SES::ReceiptFilter",
     "AWS::SES::ReceiptRule",
     "AWS::SES::ReceiptRuleSet",
@@ -1145,6 +1168,7 @@ types: list[str] = [
     "AWS::Transfer::Profile",
     "AWS::Transfer::Server",
     "AWS::Transfer::User",
+    "AWS::Transfer::WebApp",
     "AWS::Transfer::Workflow",
     "AWS::VerifiedPermissions::IdentitySource",
     "AWS::VerifiedPermissions::Policy",
@@ -1191,6 +1215,7 @@ types: list[str] = [
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
+    "AWS::XRay::TransactionSearchConfig",
     "Alexa::ASK::Skill",
     "Module",
 ]
@@ -1235,12 +1260,10 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1250,6 +1273,7 @@ cached: list[str] = [
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
+    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -1261,6 +1285,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
+    "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -1293,6 +1318,7 @@ cached: list[str] = [
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
+    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -1328,6 +1354,7 @@ cached: list[str] = [
     "aws-backup-restoretestingselection.json",
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
@@ -1338,7 +1365,6 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
@@ -1356,9 +1382,6 @@ cached: list[str] = [
     "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
-    "aws-cleanrooms-analysistemplate.json",
-    "aws-cleanrooms-collaboration.json",
-    "aws-cleanrooms-configuredtable.json",
     "aws-cleanrooms-configuredtableassociation.json",
     "aws-cleanrooms-idmappingtable.json",
     "aws-cleanrooms-idnamespaceassociation.json",
@@ -1399,6 +1422,7 @@ cached: list[str] = [
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-streamingdistribution.json",
+    "aws-cloudfront-vpcorigin.json",
     "aws-cloudtrail-channel.json",
     "aws-cloudtrail-dashboard.json",
     "aws-cloudtrail-eventdatastore.json",
@@ -1482,6 +1506,7 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
+    "aws-datazone-connection.json",
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
     "aws-datazone-environment.json",
@@ -1499,11 +1524,13 @@ cached: list[str] = [
     "aws-deadline-farm.json",
     "aws-deadline-fleet.json",
     "aws-deadline-licenseendpoint.json",
+    "aws-deadline-limit.json",
     "aws-deadline-meteredproduct.json",
     "aws-deadline-monitor.json",
     "aws-deadline-queue.json",
     "aws-deadline-queueenvironment.json",
     "aws-deadline-queuefleetassociation.json",
+    "aws-deadline-queuelimitassociation.json",
     "aws-deadline-storageprofile.json",
     "aws-detective-graph.json",
     "aws-detective-memberinvitation.json",
@@ -1530,6 +1557,8 @@ cached: list[str] = [
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
+    "aws-dsql-cluster.json",
+    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
@@ -1578,6 +1607,11 @@ cached: list[str] = [
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
+    "aws-ec2-routeserver.json",
+    "aws-ec2-routeserverassociation.json",
+    "aws-ec2-routeserverendpoint.json",
+    "aws-ec2-routeserverpeer.json",
+    "aws-ec2-routeserverpropagation.json",
     "aws-ec2-routetable.json",
     "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
@@ -1658,6 +1692,7 @@ cached: list[str] = [
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
+    "aws-elasticache-usergroup.json",
     "aws-elasticbeanstalk-application.json",
     "aws-elasticbeanstalk-applicationversion.json",
     "aws-elasticbeanstalk-configurationtemplate.json",
@@ -1782,6 +1817,7 @@ cached: list[str] = [
     "aws-guardduty-malwareprotectionplan.json",
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-healthlake-fhirdatastore.json",
     "aws-iam-accesskey.json",
@@ -1860,6 +1896,7 @@ cached: list[str] = [
     "aws-iotsitewise-assetmodel.json",
     "aws-iotsitewise-dashboard.json",
     "aws-iotsitewise-gateway.json",
+    "aws-iotsitewise-portal.json",
     "aws-iotsitewise-project.json",
     "aws-kafkaconnect-connector.json",
     "aws-kafkaconnect-customplugin.json",
@@ -1869,7 +1906,6 @@ cached: list[str] = [
     "aws-kendra-index.json",
     "aws-kendraranking-executionplan.json",
     "aws-kinesis-resourcepolicy.json",
-    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-application.json",
     "aws-kinesisanalytics-applicationoutput.json",
@@ -1939,6 +1975,7 @@ cached: list[str] = [
     "aws-lookoutvision-project.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
+    "aws-m2-environment.json",
     "aws-macie-allowlist.json",
     "aws-macie-customdataidentifier.json",
     "aws-macie-findingsfilter.json",
@@ -1962,6 +1999,7 @@ cached: list[str] = [
     "aws-medialive-cluster.json",
     "aws-medialive-eventbridgeruletemplate.json",
     "aws-medialive-eventbridgeruletemplategroup.json",
+    "aws-medialive-inputsecuritygroup.json",
     "aws-medialive-multiplex.json",
     "aws-medialive-multiplexprogram.json",
     "aws-medialive-network.json",
@@ -2029,6 +2067,7 @@ cached: list[str] = [
     "aws-oam-sink.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
     "aws-opensearchserverless-lifecyclepolicy.json",
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
@@ -2112,7 +2151,6 @@ cached: list[str] = [
     "aws-redshift-eventsubscription.json",
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
-    "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
@@ -2263,6 +2301,13 @@ cached: list[str] = [
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
+    "aws-ses-mailmanageraddoninstance.json",
+    "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanagerarchive.json",
+    "aws-ses-mailmanageringresspoint.json",
+    "aws-ses-mailmanagerrelay.json",
+    "aws-ses-mailmanagerruleset.json",
+    "aws-ses-mailmanagertrafficpolicy.json",
     "aws-ses-receiptfilter.json",
     "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
@@ -2315,6 +2360,7 @@ cached: list[str] = [
     "aws-synthetics-group.json",
     "aws-systemsmanagersap-application.json",
     "aws-timestream-database.json",
+    "aws-timestream-influxdbinstance.json",
     "aws-timestream-scheduledquery.json",
     "aws-timestream-table.json",
     "aws-transfer-agreement.json",
@@ -2323,6 +2369,7 @@ cached: list[str] = [
     "aws-transfer-profile.json",
     "aws-transfer-server.json",
     "aws-transfer-user.json",
+    "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
     "aws-verifiedpermissions-identitysource.json",
     "aws-verifiedpermissions-policy.json",
@@ -2330,9 +2377,6 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
-    "aws-vpclattice-listener.json",
-    "aws-vpclattice-resourceconfiguration.json",
-    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
@@ -2369,5 +2413,6 @@ cached: list[str] = [
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
     "aws-xray-samplingrule.json",
+    "aws-xray-transactionsearchconfig.json",
     "module.json",
 ]
