@@ -90,6 +90,7 @@ types: list[str] = [
     "AWS::Backup::ReportPlan",
     "AWS::BackupGateway::Hypervisor",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
@@ -145,6 +146,21 @@ types: list[str] = [
     "AWS::CodePipeline::Pipeline",
     "AWS::CodePipeline::Webhook",
     "AWS::CodeStarConnections::Connection",
+    "AWS::Cognito::IdentityPool",
+    "AWS::Cognito::IdentityPoolPrincipalTag",
+    "AWS::Cognito::IdentityPoolRoleAttachment",
+    "AWS::Cognito::LogDeliveryConfiguration",
+    "AWS::Cognito::ManagedLoginBranding",
+    "AWS::Cognito::UserPool",
+    "AWS::Cognito::UserPoolClient",
+    "AWS::Cognito::UserPoolDomain",
+    "AWS::Cognito::UserPoolGroup",
+    "AWS::Cognito::UserPoolIdentityProvider",
+    "AWS::Cognito::UserPoolResourceServer",
+    "AWS::Cognito::UserPoolRiskConfigurationAttachment",
+    "AWS::Cognito::UserPoolUICustomizationAttachment",
+    "AWS::Cognito::UserPoolUser",
+    "AWS::Cognito::UserPoolUserToGroupAttachment",
     "AWS::Config::AggregationAuthorization",
     "AWS::Config::ConfigRule",
     "AWS::Config::ConfigurationAggregator",
@@ -305,6 +321,7 @@ types: list[str] = [
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
     "AWS::EMRContainers::VirtualCluster",
+    "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
@@ -387,8 +404,10 @@ types: list[str] = [
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
     "AWS::GuardDuty::IPSet",
+    "AWS::GuardDuty::MalwareProtectionPlan",
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
@@ -427,6 +446,7 @@ types: list[str] = [
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::FleetMetric",
@@ -522,6 +542,7 @@ types: list[str] = [
     "AWS::Oam::Sink",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
     "AWS::OpenSearchServerless::LifecyclePolicy",
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
@@ -538,12 +559,24 @@ types: list[str] = [
     "AWS::Organizations::OrganizationalUnit",
     "AWS::Organizations::Policy",
     "AWS::Organizations::ResourcePolicy",
+    "AWS::QuickSight::Analysis",
+    "AWS::QuickSight::CustomPermissions",
+    "AWS::QuickSight::Dashboard",
+    "AWS::QuickSight::DataSet",
+    "AWS::QuickSight::DataSource",
+    "AWS::QuickSight::RefreshSchedule",
+    "AWS::QuickSight::Template",
+    "AWS::QuickSight::Theme",
+    "AWS::QuickSight::VPCConnection",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
     "AWS::RDS::DBClusterParameterGroup",
     "AWS::RDS::DBInstance",
     "AWS::RDS::DBParameterGroup",
+    "AWS::RDS::DBProxy",
+    "AWS::RDS::DBProxyEndpoint",
+    "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
     "AWS::RDS::DBSubnetGroup",
@@ -568,8 +601,10 @@ types: list[str] = [
     "AWS::RolesAnywhere::CRL",
     "AWS::RolesAnywhere::Profile",
     "AWS::RolesAnywhere::TrustAnchor",
+    "AWS::Route53::DNSSEC",
     "AWS::Route53::HealthCheck",
     "AWS::Route53::HostedZone",
+    "AWS::Route53::KeySigningKey",
     "AWS::Route53::RecordSet",
     "AWS::Route53::RecordSetGroup",
     "AWS::Route53Profiles::Profile",
@@ -618,6 +653,7 @@ types: list[str] = [
     "AWS::SSM::MaintenanceWindowTask",
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
+    "AWS::SSM::ResourceDataSync",
     "AWS::SSM::ResourcePolicy",
     "AWS::SSMGuiConnect::Preferences",
     "AWS::SSO::Application",
@@ -693,6 +729,7 @@ types: list[str] = [
     "AWS::Transfer::Profile",
     "AWS::Transfer::Server",
     "AWS::Transfer::User",
+    "AWS::Transfer::WebApp",
     "AWS::Transfer::Workflow",
     "AWS::VerifiedPermissions::Policy",
     "AWS::VerifiedPermissions::PolicyStore",
@@ -750,7 +787,15 @@ cached: list[str] = [
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
+    "aws-apigatewayv2-apimapping.json",
+    "aws-apigatewayv2-authorizer.json",
+    "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-integrationresponse.json",
+    "aws-apigatewayv2-model.json",
+    "aws-apigatewayv2-route.json",
+    "aws-apigatewayv2-routeresponse.json",
     "aws-apigatewayv2-stage.json",
+    "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
@@ -782,12 +827,14 @@ cached: list[str] = [
     "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
+    "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-backup-framework.json",
     "aws-backup-reportplan.json",
     "aws-backupgateway-hypervisor.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
@@ -797,10 +844,10 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
-    "aws-cassandra-keyspace.json",
+    "aws-bedrock-prompt.json",
+    "aws-bedrock-promptversion.json",
     "aws-cassandra-table.json",
     "aws-cassandra-type.json",
     "aws-certificatemanager-account.json",
@@ -837,6 +884,21 @@ cached: list[str] = [
     "aws-codepipeline-pipeline.json",
     "aws-codepipeline-webhook.json",
     "aws-codestarconnections-connection.json",
+    "aws-cognito-identitypool.json",
+    "aws-cognito-identitypoolprincipaltag.json",
+    "aws-cognito-identitypoolroleattachment.json",
+    "aws-cognito-logdeliveryconfiguration.json",
+    "aws-cognito-managedloginbranding.json",
+    "aws-cognito-userpool.json",
+    "aws-cognito-userpoolclient.json",
+    "aws-cognito-userpooldomain.json",
+    "aws-cognito-userpoolgroup.json",
+    "aws-cognito-userpoolidentityprovider.json",
+    "aws-cognito-userpoolresourceserver.json",
+    "aws-cognito-userpoolriskconfigurationattachment.json",
+    "aws-cognito-userpooluicustomizationattachment.json",
+    "aws-cognito-userpooluser.json",
+    "aws-cognito-userpoolusertogroupattachment.json",
     "aws-config-configurationaggregator.json",
     "aws-config-configurationrecorder.json",
     "aws-config-conformancepack.json",
@@ -875,6 +937,7 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
+    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
@@ -940,11 +1003,15 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-verifiedaccessendpoint.json",
     "aws-ec2-verifiedaccessgroup.json",
+    "aws-ec2-verifiedaccessinstance.json",
+    "aws-ec2-verifiedaccesstrustprovider.json",
     "aws-ec2-volume.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
     "aws-ec2-vpcblockpublicaccessoptions.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
@@ -990,6 +1057,7 @@ cached: list[str] = [
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
     "aws-emrcontainers-virtualcluster.json",
+    "aws-emrserverless-application.json",
     "aws-events-archive.json",
     "aws-events-eventbuspolicy.json",
     "aws-eventschemas-discoverer.json",
@@ -1003,6 +1071,7 @@ cached: list[str] = [
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
     "aws-glue-classifier.json",
+    "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
     "aws-glue-datacatalogencryptionsettings.json",
@@ -1028,8 +1097,10 @@ cached: list[str] = [
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
     "aws-guardduty-ipset.json",
+    "aws-guardduty-malwareprotectionplan.json",
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-iam-accesskey.json",
     "aws-iam-grouppolicy.json",
@@ -1059,6 +1130,7 @@ cached: list[str] = [
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
+    "aws-iot-command.json",
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-fleetmetric.json",
@@ -1080,7 +1152,6 @@ cached: list[str] = [
     "aws-iot-topicrule.json",
     "aws-iot-topicruledestination.json",
     "aws-kinesis-resourcepolicy.json",
-    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
@@ -1142,7 +1213,9 @@ cached: list[str] = [
     "aws-oam-sink.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
     "aws-opensearchserverless-lifecyclepolicy.json",
+    "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
     "aws-opsworks-app.json",
@@ -1156,11 +1229,20 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-quicksight-analysis.json",
+    "aws-quicksight-custompermissions.json",
+    "aws-quicksight-dashboard.json",
+    "aws-quicksight-datasource.json",
+    "aws-quicksight-refreshschedule.json",
+    "aws-quicksight-template.json",
+    "aws-quicksight-theme.json",
+    "aws-quicksight-vpcconnection.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
+    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
@@ -1184,7 +1266,9 @@ cached: list[str] = [
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
+    "aws-route53-dnssec.json",
     "aws-route53-hostedzone.json",
+    "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
     "aws-route53profiles-profile.json",
@@ -1203,6 +1287,7 @@ cached: list[str] = [
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-storagelensgroup.json",
     "aws-s3objectlambda-accesspoint.json",
@@ -1281,6 +1366,7 @@ cached: list[str] = [
     "aws-ssm-maintenancewindowtask.json",
     "aws-ssm-parameter.json",
     "aws-ssm-patchbaseline.json",
+    "aws-ssm-resourcedatasync.json",
     "aws-ssm-resourcepolicy.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
