@@ -1,6 +1,9 @@
 """
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
+
+# Code is taken from jsonschema package and adapted CloudFormation use
+# https://github.com/yaml/pyyaml/blob/a2d19c0234866dc9d4d55abf3009699c258bb72f/lib/yaml/scanner.py#L46
 """
 
 import fileinput
@@ -14,8 +17,10 @@ from yaml.reader import Reader
 from yaml.resolver import Resolver
 from yaml.scanner import Scanner
 
-import cfnlint
-from cfnlint.decode.node import dict_node, list_node, str_node, sub_node
+from cfnlint.decode.mark import Mark
+from cfnlint.decode.node import dict_node, list_node, str_node
+from cfnlint.rules import Match
+from cfnlint.rules.errors import ParseError
 
 try:
     from yaml._yaml import CParser as Parser  # pylint: disable=ungrouped-imports,
@@ -38,7 +43,7 @@ class CfnParseError(ConstructorError):
     """
 
     def __init__(self, filename, errors):
-        if isinstance(errors, cfnlint.rules.Match):
+        if isinstance(errors, Match):
             errors = [errors]
 
         # Call the base class constructor with the parameters it needs
@@ -50,14 +55,14 @@ class CfnParseError(ConstructorError):
 
 
 def build_match(filename, message, line_number, column_number, key):
-    return cfnlint.rules.Match(
-        line_number + 1,
-        column_number + 1,
-        line_number + 1,
-        column_number + 1 + len(key),
-        filename,
-        cfnlint.rules.ParseError(),
+    return Match.create(
         message=message,
+        filename=filename,
+        rule=ParseError(),
+        linenumber=line_number + 1,
+        columnnumber=column_number + 1,
+        linenumberend=line_number + 1,
+        columnnumberend=column_number + 1 + len(key),
     )
 
 
@@ -69,9 +74,15 @@ class NodeConstructor(SafeConstructor):
     def __init__(self, filename):
         # Call the base class constructor
         super().__init__()
-
         self.filename = filename
 
+    def flatten_mapping(self, node):
+        # Rewrote to handle merging and overwriting keys
+        if any(key_node.tag == "tag:yaml.org,2002:merge" for key_node, _ in node.value):
+            super().flatten_mapping(node)
+            setattr(node, "using_merge", True)
+        super().flatten_mapping(node)
+
     # To support lazy loading, the original constructors first yield
     # an empty object, then fill them in when iterated. Due to
     # laziness we omit this behaviour (and will only do "deep
@@ -94,44 +105,57 @@ class NodeConstructor(SafeConstructor):
                     [
                         build_match(
                             filename=self.filename,
-                            message=f"Null key {key_node.value!r} not supported (line {key_node.start_mark.line + 1})",
+                            message=(
+                                f"Null key {key_node.value!r} not supported "
+                                f"(line {key_node.start_mark.line + 1})"
+                            ),
                             line_number=key_node.start_mark.line,
                             column_number=key_node.start_mark.column,
                             key=key_node.value,
                         ),
                     ],
                 )
-            for key_dup in mapping:
-                if key_dup == key:
-                    if not matches:
-                        matches.extend(
-                            [
+            if not getattr(node, "using_merge", False):
+                for key_dup in mapping:
+                    if key_dup == key:
+                        if matches:
+                            matches.append(
                                 build_match(
                                     filename=self.filename,
-                                    message=f'Duplicate found "{key}" (line {key_dup.start_mark.line + 1})',
-                                    line_number=key_dup.start_mark.line,
-                                    column_number=key_dup.start_mark.column,
-                                    key=key,
-                                ),
-                                build_match(
-                                    filename=self.filename,
-                                    message=f'Duplicate found "{key}" (line {key_node.start_mark.line + 1})',
+                                    message=(
+                                        f"Duplicate found {key!r} (line"
+                                        f" {key_node.start_mark.line + 1})"
+                                    ),
                                     line_number=key_node.start_mark.line,
                                     column_number=key_node.start_mark.column,
                                     key=key,
-                                ),
-                            ],
-                        )
-                    else:
-                        matches.append(
-                            build_match(
-                                filename=self.filename,
-                                message=f'Duplicate found "{key}" (line {key_node.start_mark.line + 1})',
-                                line_number=key_node.start_mark.line,
-                                column_number=key_node.start_mark.column,
-                                key=key,
-                            ),
-                        )
+                                )
+                            )
+                        else:
+                            matches.extend(
+                                [
+                                    build_match(
+                                        filename=self.filename,
+                                        message=(
+                                            f"Duplicate found {key!r} (line"
+                                            f" {key_dup.start_mark.line + 1})"
+                                        ),
+                                        line_number=key_dup.start_mark.line,
+                                        column_number=key_dup.start_mark.column,
+                                        key=key,
+                                    ),
+                                    build_match(
+                                        filename=self.filename,
+                                        message=(
+                                            f"Duplicate found {key!r} (line"
+                                            f" {key_node.start_mark.line + 1})"
+                                        ),
+                                        line_number=key_node.start_mark.line,
+                                        column_number=key_node.start_mark.column,
+                                        key=key,
+                                    ),
+                                ],
+                            )
             try:
                 mapping[key] = value
             except Exception as exc:
@@ -140,7 +164,10 @@ class NodeConstructor(SafeConstructor):
                     [
                         build_match(
                             filename=self.filename,
-                            message=f'Unhashable type "{key}" (line {key.start_mark.line + 1})',
+                            message=(
+                                f'Unhashable type "{key}" (line'
+                                f" {key.start_mark.line + 1})"
+                            ),
                             line_number=key.start_mark.line,
                             column_number=key.start_mark.column,
                             key=key,
@@ -156,11 +183,8 @@ class NodeConstructor(SafeConstructor):
 
         (obj,) = SafeConstructor.construct_yaml_map(self, node)
 
-        if len(mapping) == 1:
-            if "Fn::Sub" in mapping:
-                return sub_node(obj, node.start_mark, node.end_mark)
-
-        return dict_node(obj, node.start_mark, node.end_mark)
+        using_merge = False if not hasattr(node, "using_merge") else node.using_merge
+        return dict_node(obj, node.start_mark, node.end_mark, using_merge)
 
     def construct_yaml_str(self, node):
         obj = SafeConstructor.construct_yaml_str(self, node)
@@ -186,8 +210,33 @@ NodeConstructor.add_constructor(  # type: ignore
 )
 
 
+class _Scanner(Scanner):
+
+    def __init__(self) -> None:
+        super().__init__()
+        self.ESCAPE_REPLACEMENTS = {
+            "0": "\0",
+            "a": "\x07",
+            "b": "\x08",
+            "t": "\x09",
+            "\t": "\x09",
+            "n": "\x0A",
+            "v": "\x0B",
+            "f": "\x0C",
+            "r": "\x0D",
+            "e": "\x1B",
+            " ": "\x20",
+            '"': '"',
+            "\\": "\\",
+            "N": "\x85",
+            "_": "\xA0",
+            "L": "\u2028",
+            "P": "\u2029",
+        }
+
+
 # pylint: disable=too-many-ancestors
-class MarkedLoader(Reader, Scanner, Parser, Composer, NodeConstructor, Resolver):
+class MarkedLoader(Reader, _Scanner, Parser, Composer, NodeConstructor, Resolver):
     """
     Class for marked loading YAML
     """
@@ -196,7 +245,7 @@ class MarkedLoader(Reader, Scanner, Parser, Composer, NodeConstructor, Resolver)
 
     def __init__(self, stream, filename):
         Reader.__init__(self, stream)
-        Scanner.__init__(self)
+        _Scanner.__init__(self)
         if cyaml:
             Parser.__init__(self, stream)
         else:
@@ -239,9 +288,6 @@ def multi_constructor(loader, tag_suffix, node):
     else:
         raise f"Bad tag: !{tag_suffix}"
 
-    if tag_suffix == "Fn::Sub":
-        return sub_node({tag_suffix: constructor(node)}, node.start_mark, node.end_mark)
-
     return dict_node({tag_suffix: constructor(node)}, node.start_mark, node.end_mark)
 
 
@@ -254,7 +300,7 @@ def loads(yaml_string, fname=None):
     template = loader.get_single_data()
     # Convert an empty file to an empty dict
     if template is None:
-        template = {}
+        template = dict_node({}, Mark(0, 0), Mark(0, 0))
 
     return template
 
@@ -266,15 +312,13 @@ def load(filename):
 
     content = ""
 
-    if not sys.stdin.isatty():
-        filename = "-" if filename is None else filename
-        if sys.version_info.major <= 3 and sys.version_info.minor <= 9:
-            for line in fileinput.input(files=filename):
-                content = content + line
-        else:
-            for line in fileinput.input(  # pylint: disable=unexpected-keyword-arg
-                files=filename, encoding="utf-8"
-            ):
+    if (filename is None) and (not sys.stdin.isatty()):
+        filename = "-"  # no filename provided, it's stdin
+        fileinput_args = {"files": filename}
+        if sys.version_info.major <= 3 and sys.version_info.minor >= 10:
+            fileinput_args["encoding"] = "utf-8"
+        with fileinput.input(**fileinput_args) as f:
+            for line in f:
                 content = content + line
     else:
         with open(filename, encoding="utf-8") as fp:
