@@ -31,6 +31,7 @@ class Sub(BaseFn):
             {
                 "W1019": None,
                 "W1020": None,
+                "W1051": None,
             }
         )
         self._functions = [
@@ -142,9 +143,14 @@ class Sub(BaseFn):
 
         # we know the structure is valid at this point
         # so any child rule doesn't have to revalidate it
+        value_validator = validator.evolve(
+            context=validator.context.evolve(
+                path=validator.context.path.descend(path=key)
+            )
+        )
         for _, rule in self.child_rules.items():
             if rule and hasattr(rule, "validate"):
-                for err in rule.validate(validator, s, instance.get("Fn::Sub"), schema):
+                for err in rule.validate(value_validator, s, value, schema):
                     err.path.append("Fn::Sub")
                     err.rule = rule
                     yield err
