@@ -10,7 +10,6 @@ import json
 import logging
 import random
 import string
-import sys
 from copy import deepcopy
 from typing import Any, Iterator, Mapping, MutableMapping, Tuple
 
@@ -126,7 +125,7 @@ class _Transform:
                     # only translate the foreach if its valid
                     foreach = _ForEach(k, v, self._collections)
                     # get the values will flatten the foreach
-                    for collection_value in foreach.items(cfn):
+                    for collection_value in foreach.items(cfn, params):
                         flattened = self._walk(
                             v[2], {**params, **{v[0]: collection_value}}, cfn
                         )
@@ -207,16 +206,11 @@ class _Transform:
         new_s = deepcopy(s)
         for k, v in params.items():
             if isinstance(v, dict):
-                if sys.version_info.major == 3 and sys.version_info.minor > 8:
-                    v = (
-                        hashlib.md5(
-                            json.dumps(v).encode("utf-8"), usedforsecurity=False
-                        )
-                        .digest()
-                        .hex()[0:4]
-                    )
-                else:
-                    v = hashlib.md5(json.dumps(v).encode("utf-8")).digest().hex()[0:4]
+                v = (
+                    hashlib.md5(json.dumps(v).encode("utf-8"), usedforsecurity=False)
+                    .digest()
+                    .hex()[0:4]
+                )
             new_s = re.sub(rf"\$\{{{k}\}}", v, new_s)
             new_s = re.sub(rf"\&\{{{k}\}}", re.sub("[^0-9a-zA-Z]+", "", v), new_s)
 
@@ -247,6 +241,8 @@ class _ForEachValue:
                     return _ForEachValueRef(_hash, v)
                 if k == "Fn::FindInMap":
                     return _ForEachValueFnFindInMap(_hash, v)
+                if k == "Fn::If":
+                    return _ForEachValueFnIf(_hash, v)
 
         raise _TypeError(f"Unsupported value {obj!r}", obj)
 
@@ -392,19 +388,25 @@ class _ForEachValueFnFindInMap(_ForEachValue):
 
         if mapping:
             try:
-                return mapping.get(t_map[1].value(cfn, params, only_params), {}).get(
+                value = mapping.get(t_map[1].value(cfn, params, only_params), {}).get(
                     t_map[2].value(cfn, params, only_params)
                 )
+                if value is None:
+                    raise _ResolveError("Can't resolve Fn::FindInMap", self._obj)
+                return value
             except _ResolveError as e:
                 if len(self._map) == 4 and default_on_resolver_failure:
                     return self._map[3].value(cfn, params, only_params)
                 # no default value and map 1 exists
                 try:
-                    for _, v in mapping.get(
-                        t_map[1].value(cfn, params, only_params), {}
-                    ).items():
-                        if isinstance(v, list):
-                            return v
+                    if isinstance(
+                        t_map[2], (_ForEachValueRef, _ForEachValueFnFindInMap)
+                    ):
+                        for _, v in mapping.get(
+                            t_map[1].value(cfn, params, only_params), {}
+                        ).items():
+                            if isinstance(v, list):
+                                return v
                 except _ResolveError:
                     pass
                 raise _ResolveError("Can't resolve Fn::FindInMap", self._obj) from e
@@ -414,6 +416,27 @@ class _ForEachValueFnFindInMap(_ForEachValue):
         raise _ResolveError("Can't resolve Fn::FindInMap", self._obj)
 
 
+class _ForEachValueFnIf(_ForEachValue):
+    def __init__(self, _hash: str, obj: Any) -> None:
+        super().__init__(_hash)
+        if not isinstance(obj, (list)):
+            raise _TypeError("Fn::If should be a list of 3 elements", obj)
+
+        if len(obj) != 3:
+            raise _TypeError("Fn::If should be a list of 3 elements", obj)
+        self._condition = _ForEachValue.create(obj[0])
+        self._obj = obj
+
+    # pylint: disable=too-many-return-statements
+    def value(
+        self,
+        cfn: Any,
+        params: Mapping[str, Any] | None = None,
+        only_params: bool = False,
+    ) -> Any:
+        raise _ResolveError("Can't resolve Fn::If", self._obj)
+
+
 class _ForEachValueRef(_ForEachValue):
     def __init__(self, _hash: str, obj: Any) -> None:
         super().__init__(_hash)
@@ -523,7 +546,10 @@ class _ForEachCollection:
         raise _TypeError("Collection must be a list or an object", obj)
 
     def values(
-        self, cfn: Any, collection_cache: MutableMapping[str, Any]
+        self,
+        cfn: Any,
+        collection_cache: MutableMapping[str, Any],
+        params: MutableMapping[str, Any],
     ) -> Iterator[str | dict[Any, Any]]:
         if self._collection:
             for item in self._collection:
@@ -536,7 +562,7 @@ class _ForEachCollection:
             return
         if self._fn:
             try:
-                values = self._fn.value(cfn, {}, False)
+                values = self._fn.value(cfn, params, False)
                 if values is not None:
                     if isinstance(values, list):
                         for value in values:
@@ -594,6 +620,8 @@ class _ForEach:
         self._collection = _ForEachCollection(value[1])
         self._output = _ForEachOutput(value[2])
 
-    def items(self, cfn: Any) -> Iterator[str | dict[str, str]]:
-        items = self._collection.values(cfn, self._collection_cache)
+    def items(
+        self, cfn: Any, params: MutableMapping[str, Any]
+    ) -> Iterator[str | dict[str, str]]:
+        items = self._collection.values(cfn, self._collection_cache, params)
         yield from iter(items)
